@@ -4,6 +4,7 @@ import logging
 import os
 import shutil
 import sys
+import subprocess
 import unittest
 import tempfile
 
@@ -456,4 +457,30 @@ class CollectionTest(unittest.TestCase):
     def test_no_read_directory(self):
         self.assertRaises(ValueError, fiona.open, "/dev/null", "r")
 
+class GeoJSONCRSWritingTest(unittest.TestCase):
+
+    def setUp(self):
+        self.tempdir = tempfile.mkdtemp()
+        self.filename = os.path.join(self.tempdir, "crs_writing_test.json")
+        self.sink = fiona.open(
+            self.filename,
+            "w",
+            driver="GeoJSON",
+            schema={
+                'geometry': 'Point', 
+                'properties': [('title', 'str'), ('date', 'date')]},
+            crs={'a': 6370997, 'lon_0': -100, 'y_0': 0, 'no_defs': True, 'proj': 'laea', 'x_0': 0, 'units': 'm', 'b': 6370997, 'lat_0': 45})
+
+    def tearDown(self):
+        self.sink.close()
+        shutil.rmtree(self.tempdir)
+
+    def test_crs(self):
+        """OGR's GeoJSON driver only deals in WGS84"""
+        self.sink.close()
+        info = subprocess.check_output(
+            ["ogrinfo", self.filename, "OGRGeoJSON"])
+        self.assert_(
+            'GEOGCS["WGS 84' in info,
+            info)
 
