@@ -2,7 +2,8 @@
 from fiona import crs
 
 def test_proj_keys():
-    assert len(crs.all_proj_keys) == 85
+    assert len(crs.all_proj_keys) == 86
+    assert 'init' in crs.all_proj_keys
     assert 'proj' in crs.all_proj_keys
     assert 'no_mayo' in crs.all_proj_keys
 
@@ -43,6 +44,10 @@ def test_to_string_utm():
     assert crs.to_string(
         val) == "+ellps=WGS84 +no_defs +proj=utm +zone=13"
 
+def test_to_string_epsg():
+    val = {'init': 'epsg:4326', 'no_defs': True}
+    assert crs.to_string(val) == "+init=epsg:4326 +no_defs"
+
 def test_from_epsg():
     val = crs.from_epsg(4326)
     assert val['init'] == "epsg:4326"
